﻿using System;
using System.Collections.Generic;
using System.ComponentModel;
using System.Data;
using System.Drawing;
using System.Linq;
using System.Text;
using System.Windows.Forms;
using System.Xml;
using System.Xml.Serialization;
using System.IO;
using System.Runtime.Serialization.Formatters.Binary;

namespace CSWindowsApplication
{
    public partial class SerializationExample : Form
    {
        //Declare an instance of the Custom Class that we want to Serialize
        //This will be used for both the Binary and XML Serialization
        private CustomSettings customSettings;

        public SerializationExample()
        {
            InitializeComponent();
        }

        //Create a new instance of the Custom Class to hold all the information
        private void SerializationExample_Load(object sender, EventArgs e)
        {
            customSettings = new CustomSettings();
        }

        //Serialize the information using the Binary Formatter
        private void SerializeBinaryButton_Click(object sender, EventArgs e)
        {
            //Grab the information from the TextBoxes
            GetCustomSettingsFromTextBoxes();

            //Create a file to save the data to
            FileStream fs = new FileStream("SerializeBinary.data", FileMode.Create);

            //Create a BinaryFormatter object to perform the serialization
            BinaryFormatter bf = new BinaryFormatter();

            //Use the BinaryFormatter object to serialize the data to the file
            bf.Serialize(fs, customSettings);

            //Close the file
            fs.Close();

            //Reset the Textboxes to blank so that we can prove the deserilization
            ResetControls();
        }

        private void SerializeXMLButton_Click(object sender, EventArgs e)
        {
            //Grab the information from the TextBoxes
            GetCustomSettingsFromTextBoxes();

            //Create the file to save the data to
            FileStream fs = new FileStream("SerializeXML.xml", FileMode.Create);

            //Create an XmlSerializer object to perfrom the serialization
            XmlSerializer xs = new XmlSerializer(typeof(CustomSettings));

            //User the XmlSerializer object to serialize the data to the file
            xs.Serialize(fs, customSettings);

            //Close the file
            fs.Close();

            //Reset the Textboxes to blank so that we can prove the deserilization
            ResetControls();
        }

        private void DeserializeBinaryButton_Click(object sender, EventArgs e)
        {
            //Check to see if the file exists
            if (File.Exists("SerializeBinary.data"))
            {
                //Open file to read the data from
                FileStream fs = new FileStream("SerializeBinary.data", FileMode.Open);

                //Create a BinaryFormatter object to perform the deserialization
                BinaryFormatter bf = new BinaryFormatter();

                //Use the BinaryFormatter object to deserilize the data from the file
                customSettings = (CustomSettings)bf.Deserialize(fs);

                //Set the textboxes with the values stored in the customSettings class
                SetTextBoxesFromCustomSettings();

                //Close the file
                fs.Close();
            }
        }

        private void DeserialzeXMLButton_Click(object sender, EventArgs e)
        {
            //Check to see if the file exists
            if (File.Exists("SerializeXML.xml"))
            {
                //Open file to read the data from
                FileStream fs = new FileStream("SerializeXML.xml", FileMode.Open);

                //Create an XmlSerializer object to perfrom the deserialization
                XmlSerializer xs = new XmlSerializer(typeof(CustomSettings));

                //use the XmlSerializer object to deserialize the data from the file
                customSettings = (CustomSettings)xs.Deserialize(fs);

                //Set the textboxes with the values stored in the customSettings class
                SetTextBoxesFromCustomSettings();

                //Close the file
                fs.Close();
            }
        }

        private void ResetButton_Click(object sender, EventArgs e)
        {
            ResetControls();
        }

        # region "Worker Methods"

        //Reset the TextBoxes to blanks
        private void ResetControls()
        {
            CustomSetting1TextBox.Text = String.Empty;
            CustomSetting2TextBox.Text = String.Empty;
            CustomSetting3TextBox.Text = String.Empty;
            CustomSetting4TextBox.Text = String.Empty;
            CustomSetting5TextBox.Text = String.Empty;
            CustomSetting6TextBox.Text = String.Empty;
        }

        //Populate the values of the Custom Class based on the values in the text box
        private void GetCustomSettingsFromTextBoxes()
        {
            customSettings.CustomSetting1 = CustomSetting1TextBox.Text;
            customSettings.CustomSetting2 = CustomSetting2TextBox.Text;
            customSettings.CustomSetting3 = CustomSetting3TextBox.Text;
            customSettings.CustomSetting4 = CustomSetting4TextBox.Text;
            customSettings.CustomSetting5 = CustomSetting5TextBox.Text;
            customSettings.CustomSetting6 = CustomSetting6TextBox.Text;
        }

        //Populate the TextBoxes based on what is stored in the instance of the custom class
        private void SetTextBoxesFromCustomSettings()
        {
            CustomSetting1TextBox.Text = customSettings.CustomSetting1;
            CustomSetting2TextBox.Text = customSettings.CustomSetting2;
            CustomSetting3TextBox.Text = customSettings.CustomSetting3;
            CustomSetting4TextBox.Text = customSettings.CustomSetting4;
            CustomSetting5TextBox.Text = customSettings.CustomSetting5;
            CustomSetting6TextBox.Text = customSettings.CustomSetting6;

            //reset the values in the custom class to be sure we aren't storing any other values than
            //the ones that we are expecting
            customSettings.CustomSetting1 = String.Empty;
            customSettings.CustomSetting2 = String.Empty;
            customSettings.CustomSetting3 = String.Empty;
            customSettings.CustomSetting4 = String.Empty;
            customSettings.CustomSetting5 = String.Empty;
            customSettings.CustomSetting6 = String.Empty;
        }

        # endregion

    }
}
